==> rgu34a.db_2.2.5.tar.gz: rgu34a.db/man/rgu34a_dbconn.Rd <==
\name{rgu34a_dbconn}

\alias{rgu34a_dbconn}
\alias{rgu34a_dbfile}
\alias{rgu34a_dbschema}
\alias{rgu34a_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  rgu34a_dbconn()
  rgu34a_dbfile()
  rgu34a_dbschema(file="", show.indices=FALSE)
  rgu34a_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{rgu34a_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{rgu34a_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{rgu34a_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{rgu34a_dbschema} prints the schema definition of the
  package annotation DB.

  \code{rgu34a_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{rgu34a_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{rgu34a_dbfile}: a character string with the path to the
  package annotation DB.

  \code{rgu34a_dbschema}: none (invisible \code{NULL}).

  \code{rgu34a_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(rgu34a_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by rgu34a_dbconn() was created with:
  dbConnect(SQLite(), dbname=rgu34a_dbfile(), cache_size=64000, synchronous=0)

  rgu34a_dbschema()

  rgu34a_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> rgu34a.db_2.14.0.tar.gz: rgu34a.db/man/rgu34a_dbconn.Rd <==

\name{rgu34a_dbconn}

\alias{rgu34a_dbconn}
\alias{rgu34a_dbfile}
\alias{rgu34a_dbschema}
\alias{rgu34a_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  rgu34a_dbconn()
  rgu34a_dbfile()
  rgu34a_dbschema(file="", show.indices=FALSE)
  rgu34a_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{rgu34a_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{rgu34a_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{rgu34a_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{rgu34a_dbschema} prints the schema definition of the
  package annotation DB.

  \code{rgu34a_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{rgu34a_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{rgu34a_dbfile}: a character string with the path to the
  package annotation DB.

  \code{rgu34a_dbschema}: none (invisible \code{NULL}).

  \code{rgu34a_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(rgu34a_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by rgu34a_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=rgu34a_dbfile(), cache_size=64000,
  synchronous=0)

  rgu34a_dbschema()

  rgu34a_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
